@@ -8,14 +8,21 @@ module_selection = function(i,
                             response_matrix,
                             seen_cat_items,
                             cat_length,
+                            module_select,
                             initial_theta = 0) {
+  if (is.null(module_select)|
+      !(module_select %in% c("MFI", "MLWMI", "MPWMI", "MKL", "MKLP", "random"))) {
+        module_select <- "MFI"
+      }
+
   next.module = mstR::nextModule(
     itemBank = module_item_bank,
     modules = modules,
     transMatrix = transition_matrix,
     current.module = 1,
     out = c(1:cat_length),
-    theta = theta_est
+    theta = theta_est,
+    criterion = module_select
   )
 
   current.responses = as.numeric(c(response_matrix[i, c(seen_cat_items)], response_matrix[i, c(rownames(next.module$par))]))
@@ -76,7 +83,12 @@ moduleSelectionCAMST = function(i,
                                 seen_cat_items,
                                 cat_length,
                                 initial_theta = 0,
-                                n_stage) {
+                                n_stage,
+                                module_select = NULL) {
+  if (is.null(module_select)|
+      !(module_select %in% c("MFI", "MLWMI", "MPWMI", "MKL", "MKLP", "random"))) {
+    module_select <- "MFI"
+  }
   seen.modules = 1
   seen.items = seen_cat_items
   for (m in 2:n_stage) {
